@@ -4,18 +4,23 @@ from __future__ import unicode_literals
 #: Name pieces that appear before a last name. They join to the piece that follows them to make one new piece.
 PREFIXES = set([
     'abu',
-    'bon',
     'bin',
+    'bon',
     'da',
     'dal',
     'de',
+    'degli',
+    'dei',
     'del',
     'dela',
+    'della',
+    'delle',
+    'delli',
+    'dello',
     'der',
-    'de',
     'di',
-    'dí',
     'du',
+    'dí',
     'ibn',
     'la',
     'le',
