@@ -2,6 +2,7 @@
 from __future__ import unicode_literals
 
 SUFFIX_NOT_ACRONYMS = set([
+    'dr',
     'esq',
     'esquire',
     'jr',
@@ -72,6 +73,7 @@ SUFFIX_ACRONYMS = set([
     'idsm',
     'iom',
     'iso',
+    'jd',
     'kbe',
     'kcb',
     'kcie',
