@@ -11,6 +11,7 @@ from nameparser.util import lc
 from nameparser.util import log
 from nameparser.config import CONSTANTS
 from nameparser.config import Constants
+from nameparser.config import DEFAULT_ENCODING
 
 ENCODING = 'utf-8'
 
@@ -69,14 +70,15 @@ class HumanName(object):
     unparsable = True
     _full_name = ''
     
-    def __init__(self, full_name="", constants=CONSTANTS, encoding=ENCODING, 
+    def __init__(self, full_name="", constants=CONSTANTS, encoding=DEFAULT_ENCODING,
                 string_format=None):
         self.C = constants
         if type(self.C) is not type(CONSTANTS):
             self.C = Constants()
         
-        self.ENCODING = encoding
+        self.encoding = encoding
         self.string_format = string_format or self.C.string_format
+        # full_name setter triggers the parse
         self.full_name = full_name
     
     def __iter__(self):
@@ -126,15 +128,15 @@ class HumanName(object):
         if self.string_format:
             # string_format = "{title} {first} {middle} {last} {suffix} ({nickname})"
             _s = self.string_format.format(**self.as_dict())
-            # remove trailing punctation from missing nicknames
+            # remove trailing punctuation from missing nicknames
             _s = _s.replace(str(self.C.empty_attribute_default),'').replace(" ()","").replace(" ''","").replace(' ""',"")
             return self.collapse_whitespace(_s).strip(', ')
         return " ".join(self)
     
     def __str__(self):
-        if sys.version >= '3':
+        if sys.version_info[0] >= 3:
             return self.__unicode__()
-        return self.__unicode__().encode(self.ENCODING)
+        return self.__unicode__().encode(self.encoding)
     
     def __repr__(self):
         if self.unparsable:
@@ -149,9 +151,9 @@ class HumanName(object):
                 'suffix': self.suffix or '',
                 'nickname': self.nickname or '',
             }
-        if sys.version >= '3':
+        if sys.version_info[0] >= 3:
             return _string
-        return _string.encode(self.ENCODING)
+        return _string.encode(self.encoding)
     
     def as_dict(self, include_empty=True):
         """
@@ -354,7 +356,7 @@ class HumanName(object):
         self.original = value
         self._full_name = value
         if isinstance(value, binary_type):
-            self._full_name = value.decode(self.ENCODING)
+            self._full_name = value.decode(self.encoding)
         self.parse_full_name()
     
     def collapse_whitespace(self, string):
@@ -371,7 +373,7 @@ class HumanName(object):
         
         """
         self.parse_nicknames()
-        
+        self.squash_emoji()
 
     def post_process(self):
         """
@@ -392,6 +394,14 @@ class HumanName(object):
             self.nickname_list = re_nickname.findall(self._full_name)
             self._full_name = re_nickname.sub('', self._full_name)
 
+    def squash_emoji(self):
+        """
+        Remove emoji from the input string.
+        """
+        re_emoji = self.C.regexes.emoji
+        if re_emoji and re_emoji.search(self._full_name):
+            self._full_name = re_emoji.sub('', self._full_name)
+
     def handle_firstnames(self):
         """
         If there are only two parts and one is a title, assume it's a last name
@@ -631,7 +641,7 @@ class HumanName(object):
         
         """
         length = len(pieces) + additional_parts_count
-        # don't join on conjuctions if there's only 2 parts
+        # don't join on conjunctions if there's only 2 parts
         if length < 3:
             return pieces
             
@@ -648,7 +658,7 @@ class HumanName(object):
         for i, val in enumerate(conj_index):
             try:
                 if conj_index[i+1] == val+1:
-                     contiguous_conj_i += [val]
+                    contiguous_conj_i += [val]
             except IndexError:
                 pass
         
@@ -670,7 +680,11 @@ class HumanName(object):
         for i in reversed(delete_i):
             # delete pieces in reverse order or the index changes on each delete
             del pieces[i]
-        
+
+        if len(pieces) == 1:
+            # if there's only one piece left, nothing left to do
+            return pieces
+
         # refresh conjunction index locations
         conj_index = [i for i, piece in enumerate(pieces) if self.is_conjunction(piece)]
         
