@@ -189,6 +189,7 @@ class HumanNamePythonTests(HumanNameTestBase):
         self.m(hn.first, "", hn)
         self.m(hn.last, "", hn)
 
+
 class FirstNameHandlingTests(HumanNameTestBase):
     def test_first_name(self):
         hn = HumanName("Andrew")
@@ -1058,7 +1059,6 @@ class HumanNameBruteForceTests(HumanNameTestBase):
         self.m(hn.last, "Almighty", hn)
 
 
-
 class HumanNameConjunctionTestCase(HumanNameTestBase):
     # Last name with conjunction
     def test_last_name_with_conjunction(self):
@@ -1244,6 +1244,11 @@ class HumanNameConjunctionTestCase(HumanNameTestBase):
         # if you want to be technical, Queen is in FIRST_NAME_TITLES
         self.m(hn.first, "Elizabeth", hn)
 
+    def test_name_is_conjunctions(self):
+        hn = HumanName("e and e")
+        self.m(hn.first, "e and e", hn)
+
+
 class ConstantsCustomization(HumanNameTestBase):
 
     def test_add_title(self):
@@ -1335,6 +1340,12 @@ class ConstantsCustomization(HumanNameTestBase):
         hn.C.empty_attribute_default = None
         self.assertEqual('', str(hn), hn)
 
+    def test_add_constant_with_explicit_encoding(self):
+        c = Constants()
+        c.titles.add_with_encoding(b'b\351ck', encoding='latin_1')
+        self.assertIn('béck', c.titles)
+
+
 class HumanNameNicknameTestCase(HumanNameTestBase):
     # https://code.google.com/p/python-nameparser/issues/detail?id=33
     def test_nickname_in_parenthesis(self):
@@ -1465,7 +1476,7 @@ class SuffixesTestCase(HumanNameTestBase):
         hn = HumanName("Kenneth Clarke QC MP")
         self.m(hn.first, "Kenneth", hn)
         self.m(hn.last, "Clarke", hn)
-        # NOTE: this adds a comma when the orginal format did not have one. 
+        # NOTE: this adds a comma when the original format did not have one.
         # not ideal but at least its in the right bucket
         self.m(hn.suffix, "QC, MP", hn)
 
@@ -1473,7 +1484,7 @@ class SuffixesTestCase(HumanNameTestBase):
         hn = HumanName("Washington Jr. MD, Franklin")
         self.m(hn.first, "Franklin", hn)
         self.m(hn.last, "Washington", hn)
-        # NOTE: this adds a comma when the orginal format did not have one. 
+        # NOTE: this adds a comma when the original format did not have one.
         self.m(hn.suffix, "Jr., MD", hn)
 
     def test_two_suffixes_suffix_comma_format(self):
@@ -1858,6 +1869,10 @@ class HumanNameCapitalizationTestCase(HumanNameTestBase):
         hn.capitalize()
         self.m(str(hn), 'Ronald McDonald', hn)
 
+    def test_short_names_with_mac(self):
+        hn = HumanName('mack johnson')
+        hn.capitalize()
+        self.m(str(hn), 'Mack Johnson', hn)
 
 class HumanNameOutputFormatTests(HumanNameTestBase):
     
@@ -1936,6 +1951,28 @@ class HumanNameOutputFormatTests(HumanNameTestBase):
         self.assertEqual(u(hn), "Rev John (Kenny) A. Kenneth Doe III")
         hn.nickname=''
         self.assertEqual(u(hn), "Rev John A. Kenneth Doe III")
+    
+    def test_remove_emojis(self):
+        hn = HumanName("Sam Smith 😊")
+        self.m(hn.first,"Sam", hn)
+        self.m(hn.last,"Smith", hn)
+        self.assertEqual(u(hn), "Sam Smith")
+
+    def test_keep_non_emojis(self):
+        hn = HumanName("∫≜⩕ Smith 😊")
+        self.m(hn.first,"∫≜⩕", hn)
+        self.m(hn.last,"Smith", hn)
+        self.assertEqual(u(hn), "∫≜⩕ Smith")
+
+    def test_keep_emojis(self):
+        from nameparser.config import Constants
+        constants = Constants()
+        constants.regexes.emoji = False
+        hn = HumanName("∫≜⩕ Smith😊", constants)
+        self.m(hn.first,"∫≜⩕", hn)
+        self.m(hn.last,"Smith😊", hn)
+        self.assertEqual(u(hn), "∫≜⩕ Smith😊")
+        # test cleanup
 
 TEST_NAMES = (
     "John Doe",
@@ -2160,8 +2197,8 @@ if __name__ == '__main__':
         name = sys.argv[1]
         hn = HumanName(name, encoding=sys.stdout.encoding)
         print((repr(hn)))
-        # hn.capitalize()
-        # print((repr(hn)))
+        hn.capitalize()
+        print((repr(hn)))
     else:
         print("-"*80)
         print("Running tests")
